@@ -53,11 +53,11 @@ class InitConnectionPool:
                                                             fromlist="ElasticsearchPool")
                         # 执行用例
                         pool = await clazz(conn_info).create_pool()
-                    # elif conn_info.dialect == "redis":
-                    #     # 获取包中用例的函数引用
-                    #     clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
-                    #     # 执行用例
-                    #     pool = await clazz(conn_info).create_pool()
+                    elif conn_info.dialect == "redis":
+                        # 获取包中用例的函数引用
+                        clazz = InitConnectionPool.getClass("lesscode.db.redis.redis_pool", fromlist="RedisPool")
+                        # 执行用例
+                        pool = await clazz(conn_info).create_pool()
                     if pool:
                         options.database[conn_info.name] = (pool, conn_info.dialect)
 
